@@ -22,6 +22,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <glib.h>
+#include <string.h>
 
 #include "tilp_core.h"
 
@@ -30,6 +31,7 @@ static gchar* cable;
 static gchar** array;
 static gchar** flist;
 static gint dont_use_gui;
+       gint silent = 0;
 extern int working_mode;
 static gint show_version;
 
@@ -38,10 +40,11 @@ static GOptionEntry entries[] =
     { "version", 0, 0, G_OPTION_ARG_NONE, &show_version, N_("Version"), NULL},
 	{ "calc", 0, 0, G_OPTION_ARG_STRING, &calc, N_("Hand-held model"), NULL },
 	{ "cable", 0, 0, G_OPTION_ARG_STRING, &cable, N_("Link cable model"), NULL },
-	{ "port", 0, 0, G_OPTION_ARG_INT, &options.cable_port, N_("Link cable port"), NULL },
-	{ "timeout", 0, 0, G_OPTION_ARG_INT, &options.cable_timeout, N_("Link cable timeout"), NULL },
-	{ "delay", 0, 0, G_OPTION_ARG_INT, &options.cable_delay, N_("Link cable delay"), NULL },
-	{ "no-gui", 0, 0, G_OPTION_ARG_NONE, &dont_use_gui, N_("Does not use GUI"), NULL },
+	{ "port", 'p', 0, G_OPTION_ARG_INT, &options.cable_port, N_("Link cable port"), NULL },
+	{ "timeout", 't', 0, G_OPTION_ARG_INT, &options.cable_timeout, N_("Link cable timeout"), NULL },
+	{ "delay", 'd', 0, G_OPTION_ARG_INT, &options.cable_delay, N_("Link cable delay"), NULL },
+	{ "no-gui", 'n', 0, G_OPTION_ARG_NONE, &dont_use_gui, N_("Does not use GUI"), NULL },
+	{ "silent", 's', 0, G_OPTION_ARG_NONE, &silent, N_("Silent mode (NO-GUI mode only"), NULL },
 	{ G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &array, N_("filename(s)"), NULL },
 	{ NULL }
 };
@@ -62,6 +65,7 @@ int tilp_cmdline_scan(int *argc, char ***argv)
 {
 	GOptionContext* context;
 	GError *error = NULL;
+	gint ret = 0;
 
 	// parse command line
 	context = g_option_context_new ("- Tilp Is a Linking Program");
@@ -97,11 +101,50 @@ int tilp_cmdline_scan(int *argc, char ***argv)
 		g_free(cable);
 	}
 
+	// look for short-options
+        if(array != NULL)
+          {
+            gchar **p;
+	    gint len;
+            int i;
+
+            // check for no extensions
+            for(p = array, len = 0; *p != NULL; p++, len++)
+              {
+                if(strrchr(*p, '.') == NULL)
+                  {
+                    for(i = 0; i < CABLE_MAX; i++)
+                      {
+                        if(!g_strcasecmp(ticables_model_to_string(i), *p))
+                          options.cable_model = i;
+                      }
+
+		    for(i = 0; i < CALC_MAX; i++)
+                      {
+                        if(!g_strcasecmp(ticalcs_model_to_string(i), *p))
+                          options.calc_model = i;
+                      }
+                  }
+	      }
+	  }
+
 	// remap for USB hand-helds
 	options.calc_model = tilp_remap_to_usb(options.cable_model,
                                                options.calc_model);
 
-	if(!options.cable_port) options.cable_port = PORT_1;
+	if(!options.cable_port)
+	{
+		switch(options.cable_model)
+		{
+		case CABLE_VTI:
+		case CABLE_TIE:
+			options.cable_port = PORT_0;
+			break;
+		default:
+			options.cable_port = PORT_1;
+			break;
+		}
+	}
 
 	// are files passed ?
 	if(array != NULL)
@@ -111,24 +154,46 @@ int tilp_cmdline_scan(int *argc, char ***argv)
 
 		working_mode = MODE_CMD;
 
-		// check whether path is local or absolute
+		// count files
 		for(p = array, len = 0; *p != NULL; p++, len++);
 
+		// allocate list of files
 		flist = g_malloc0((len + 1) * sizeof(gchar *));
 
 		// rebuild a list of file with full path
 		for(p = array, q = flist; *p != NULL; p++, q++)
 		{
+		  // skip short-options
+		  if(strrchr(*p, '.') == NULL)
+		    {
+		      q--;
+		      continue;
+		    }
+
+		  // check whether path is local or absolute
 			if (!g_path_is_absolute(*p))
 				*q = g_strconcat(g_get_current_dir(), G_DIR_SEPARATOR_S, *p, NULL);
 			else
 				*q = g_strdup(*p);
 		}
 
-		// build a pseudo file selection for TiLP
+       		// build a pseudo file selection for TiLP
 		for(q = flist; *q != NULL; q++)
-			tilp_local_selection_add(*q);
-		//tilp_local_contents_load();
+		  {
+			if(g_file_test(*q, G_FILE_TEST_EXISTS))
+			{
+				tilp_local_selection_add(*q);
+			}
+			else
+			{
+				gchar *str;
+
+				str = g_strdup_printf(_("The file <%s> does not exist."), *q);
+				gif->msg_box1(_("Error"), str);
+				g_free(str);
+				ret = -1;
+			}
+		  }
 
 		g_strfreev(array);
 		g_strfreev(flist);
@@ -140,12 +205,13 @@ int tilp_cmdline_scan(int *argc, char ***argv)
 	else
 		working_mode |= MODE_GUI;
 
-	return 0;
+	return ret;
 }
 
 /* Send files passed on the command line in no-gui mode */
 int tilp_cmdline_send(void)
 {
+	int ret = 0;
 	int over = options.overwrite;
 
 	// Check for valid selection
@@ -159,9 +225,9 @@ int tilp_cmdline_send(void)
 	if(local.selection1)
 	{
 		options.overwrite = FALSE;
-		tilp_calc_send_var();
+		ret = tilp_calc_send_var();
 		options.overwrite = over;
-		return 0;
+		return ret;
 	}
 
 	// Send OS or apps
@@ -173,15 +239,15 @@ int tilp_cmdline_send(void)
 			tifiles_file_test(fe->name, TIFILE_OS, 
 					  options.calc_model))
 		{
-			tilp_calc_send_os(fe->name);
-			return 0;
+			ret = tilp_calc_send_os(fe->name);
+			return ret;
 		}
 		else
 		{
 			options.overwrite = FALSE;
-			tilp_calc_send_app();
+			ret = tilp_calc_send_app();
 			options.overwrite = over;
-			return 0;
+			return ret;
 		}
 	}
 
@@ -190,10 +256,10 @@ int tilp_cmdline_send(void)
 	{
 		FileEntry *fe = (local.selection4)->data;
 
-		tilp_calc_send_backup(fe->name);
-		return 0;
+		ret = tilp_calc_send_backup(fe->name);
+		return ret;
 	}
 
-	return 0;
+	return ret;
 }
 
