@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_main.c 4078 2007-12-11 07:20:25Z roms $ */
+/* $Id: tilp_main.c 4191 2009-01-02 15:20:22Z roms $ */
 
 /*  TiLP - Tilp Is a Linking Program
  *  Copyright (C) 1999-2006  Romain Lievin
@@ -134,8 +134,10 @@ int tilp_init(int *argc, char ***argv)
 	 */
 	if((working_mode & MODE_CMD) && !(working_mode & MODE_GUI))
 	{
-		tilp_cmdline_send();
-		exit(0);
+		int ret;
+
+		ret = tilp_cmdline_send();
+		exit(ret);
 	}
 	else if(working_mode == MODE_INI)
 		exit(0);
