@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_paths.c 3218 2007-02-24 17:57:22Z roms $ */
+/* $Id: tilp_paths.c 4219 2009-04-29 13:59:41Z roms $ */
 
 /*  TiLP - Tilp Is a Linking Program
  *  Copyright (C) 1999-2006  Romain Lievin
@@ -30,6 +30,9 @@
 #include <windows.h>
 #endif
 
+#include <glib.h>
+#include <glib/gstdio.h>
+
 #include "tilp_core.h"
 
 TilpInstPaths inst_paths = 
@@ -114,8 +117,19 @@ static void init_win32_paths(void)
 	#ifdef __MINGW32__
 	inst_paths.home_dir = g_get_current_dir();
 	#else
-	inst_paths.home_dir = 
-	    g_strconcat(inst_paths.base_dir, "My TI files\\", NULL);
+	if((g_win32_get_windows_version() & 255) > 5)
+	{
+		// Windows Vista
+		inst_paths.home_dir = 
+			g_strconcat(g_get_home_dir(), G_DIR_SEPARATOR_S, "Documents", G_DIR_SEPARATOR_S, _("My TI Files"), NULL);
+		g_mkdir(inst_paths.home_dir, 0);
+	}
+	else
+	{
+		// Windows XP
+		inst_paths.home_dir = g_strconcat(inst_paths.base_dir, "My TI files\\", NULL);
+		g_mkdir(inst_paths.home_dir, 0);
+	}
 	#endif
 
 #ifdef ENABLE_NLS
